==> 0.4.0.tar.gz: I18N.md <==
# I18n

- [Introduction](#introduction)
- [How to use](#how-to-use)

## Introduction

Now the i18n system of day.dart contains the following keys:

- Months
- MonthsShort
- Weekdays
- WeekdaysShort
- WeekdaysMin
- AM
- PM

For example, let’s take a look at [i18n/en.dart](https://github.com/dayjs/day.dart/blob/master/lib/i18n/en.dart):

```dart
final Map<String, dynamic> Locale = {
  'Name': 'en',
  'Months': {
    1: 'January',
    2: 'February',
    3: 'March',
    4: 'April',
    5: 'May',
    6: 'June',
    7: 'July',
    8: 'August',
    9: 'September',
    10: 'October',
    11: 'November',
    12: 'December'
  },
  'Weekdays': {
    1: 'Monday',
    2: 'Tuesday',
    3: 'Wednesday',
    4: 'Thursday',
    5: 'Friday',
    6: 'Saturday',
    7: 'Sunday'
  },
  'AM': 'AM',
  'PM': 'PM'
};
```

You can see many of keys like `Months`, `Weekdays` ..., but where are the remained keys like `MonthsShort` mentioned above?

Because the `MonthsShort` is only a substring of the regular month string in English. So for example, the `MonthsShort` of `January` is `Jan`, take between 0 and 3.

The `WeekdaysShort` take between 0 and 3.

The `WeekdaysMin` take between 0 and 2.

But in different languages, the **Short** of months and weekdays isn't fully the same as in English.

You can view other locale files like [i18n/zh_cn.dart](https://github.com/dayjs/day.dart/blob/master/lib/i18n/zh_cn.dart) for more details.

## How To Use

For global usage:

```dart
import 'package:day/day.dart';
import 'package:day/i18n/zh_cn.dart' as ZH_CN_Locale;

void main() {
  Day.locale(ZH_CN_Locale.Locale);

  final d = Day.fromString('2019-04-30T10:30:30.000Z');
}
```

For local usage:

```dart
import 'package:day/day.dart';
import 'package:day/i18n/zh_cn.dart' as ZH_CN_Locale;

void main() {
  final d =
      Day.fromString('2019-04-30T10:30:30.000Z').useLocale(ZH_CN_Locale.Locale);
}
```

The local usage's priority is higher than the global usage.

==> 0.5.1.tar.gz: I18N.md <==
# I18n

- [Introduction](#introduction)
- [How to use](#how-to-use)

## Introduction

Now the i18n system of day.dart contains the following keys:

- Months
- MonthsShort
- Weekdays
- WeekdaysShort
- WeekdaysMin
- AM
- PM

For example, let’s take a look at [i18n/en.dart](https://github.com/dayjs/day.dart/blob/master/lib/i18n/en.dart):

```dart
final Map<String, dynamic> Locale = {
  'Name': 'en',
  'Months': {
    1: 'January',
    2: 'February',
    3: 'March',
    4: 'April',
    5: 'May',
    6: 'June',
    7: 'July',
    8: 'August',
    9: 'September',
    10: 'October',
    11: 'November',
    12: 'December'
  },
  'Weekdays': {
    1: 'Monday',
    2: 'Tuesday',
    3: 'Wednesday',
    4: 'Thursday',
    5: 'Friday',
    6: 'Saturday',
    7: 'Sunday'
  },
  'AM': 'AM',
  'PM': 'PM'
};
```

You can see many of keys like `Months`, `Weekdays` ..., but where are the remained keys like `MonthsShort` mentioned above?

Because the `MonthsShort` is only a substring of the regular month string in English. So for example, the `MonthsShort` of `January` is `Jan`, take between 0 and 3.

The `WeekdaysShort` take between 0 and 3.

The `WeekdaysMin` take between 0 and 2.

But in different languages, the **Short** of months and weekdays isn't fully the same as in English.

You can view other locale files like [i18n/zh_cn.dart](https://github.com/dayjs/day.dart/blob/master/lib/i18n/zh_cn.dart) for more details.

## How To Use

For global usage:

```dart
import 'package:day/day.dart';
import 'package:day/i18n/zh_cn.dart' as zhCNLocale;

void main() {
  Day.locale(zhCNLocale.locale);

  final d = Day.fromString('2019-04-30T10:30:30.000Z');
}
```

For local usage:

```dart
import 'package:day/day.dart';
import 'package:day/i18n/zh_cn.dart' as zhCNLocale;

void main() {
  final d =
      Day.fromString('2019-04-30T10:30:30.000Z').useLocale(zhCNLocale.locale);
}
```

The local usage's priority is higher than the global usage.
